Jupyter notebooks - DPRS
Author: Colin P. Stark
Description: Directed percolation and related models implemented in Rust and wrapped in Python.

Skip to content

# Jupyter notebooks

Simplified DP-class Domany-Kinzel model simulations are demonstrated in the following Jupyter notebooks:

- 1d DP for a very large lattice and large number of iterations, to validate \(t\)-decay of \(\overline\rho(t)\)

- 2d DP for a large lattice and large number of iterations, to validate \(t\)-decay of \(\overline\rho(t)\)

- 3d DP for a medium-size lattice and large number of iterations, to validate \(t\)-decay of \(\overline\rho(t)\)